import React, { useState, useEffect } from "react";
import { useNavigate } from "react-router-dom";

function StageForm() {
  const [title, setTitle] = useState("");
  const [description, setDescription] = useState("");
  const [enterpriseId, setEnterpriseId] = useState(""); // Stores selected enterprise ID
  const [enterprises, setEnterprises] = useState([]); // List of enterprises for dropdown
  const navigate = useNavigate();

  /** Fetch the list of enterprises from the backend **/
  useEffect(() => {
    fetch("http://localhost:8080/api/enterprises", {
      method: "GET",
      headers: { "Content-Type": "application/json" },
      credentials: "include",
    })
      .then((res) => res.json())
      .then((data) => {
        console.log("📌 Enterprises loaded:", data);
        setEnterprises(data);
      })
      .catch((err) => console.error("❌ Erreur lors du chargement des entreprises :", err));
  }, []);

  /** Handle form submission **/
  const handleSubmit = (e) => {
    e.preventDefault();
  
    // Ensure enterpriseId is selected
    if (!enterpriseId || enterpriseId === "none") {
      alert("❌ Veuillez sélectionner une entreprise !");
      return;
    }
  
    const newStage = {
      name: title,  // ✅ Change from "" to title
      description,
      enterprise: { id: parseInt(enterpriseId, 10) }, // Keep this as it is
    };
    
  
    console.log("📌 Sending stage data:", newStage);
  
    fetch("http://localhost:8080/api/stages/add", {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      credentials: "include",
      body: JSON.stringify(newStage), // Ensure correct format
    })
      .then((res) => {
        console.log("📌 Response status:", res.status);
  
        if (!res.ok) {
          return res.text().then((text) => {
            console.error("❌ Backend Error (text):", text);
            throw new Error(text || "Erreur inconnue");
          });
        }
  
        return res.json();
      })
      .then((data) => {
        console.log("✅ Stage added successfully:", data);
        alert("Stage ajouté avec succès !");
        setTitle("");
        setDescription("");
        setEnterpriseId(""); // Reset dropdown
        navigate("/stages");
      })
      .catch((err) => console.error("❌ Erreur lors de l'ajout du stage :", err.message));
  };
  

  /** Handle cancel button **/
  const handleCancel = () => {
    navigate("/stages"); // Redirect back to stages list
  };

  return (
    <div className="container mt-4">
      <h2>Ajouter un Stage</h2>
      <form onSubmit={handleSubmit}>
        <div className="mb-3">
          <label className="form-label">Titre du Stage</label>
          <input
            type="text"
            className="form-control"
            value={title}
            onChange={(e) => setTitle(e.target.value)}
            required
          />
        </div>
        <div className="mb-3">
          <label className="form-label">Description</label>
          <textarea
            className="form-control"
            value={description}
            onChange={(e) => setDescription(e.target.value)}
            required
          ></textarea>
        </div>
        <div className="mb-3">
          <label className="form-label">Entreprise</label>
          <select
            className="form-control"
            value={enterpriseId}
            onChange={(e) => setEnterpriseId(e.target.value)}
            required
          >
            <option value="none">Sélectionnez une entreprise</option>
            {enterprises.map((enterprise) => (
              <option key={enterprise.id} value={enterprise.id}>
                {enterprise.name}
              </option>
            ))}
          </select>
        </div>
        <div className="d-flex gap-2">
          <button type="submit" className="btn btn-primary">
            Ajouter
          </button>
          <button type="button" className="btn btn-secondary" onClick={handleCancel}>
            Annuler
          </button>
        </div>
      </form>
    </div>
  );
}

export default StageForm;
